import { useState, useEffect } from "react";
import { Header } from "@/components/Header";
import { Footer } from "@/components/Footer";
import { ProjectsHero } from "@/components/projects/ProjectsHero";
import { Button } from "@/components/ui/button";
import { motion } from "framer-motion";
import { ExternalLink } from "lucide-react";
import { supabase } from "@/integrations/supabase/client";
import { useIsMobile } from "@/hooks/use-mobile";
import { useAnalytics } from "@/hooks/useAnalytics";
import { Helmet } from "react-helmet-async";

type Project = {
  id: string;
  title: string;
  client?: string;
  type: string;
  category?: string;
  image_url: string;
  url?: string;
  description?: string;
};

// Category filter options - now filtering by type
const categories = [
  { id: "all", name: "Alle" },
  { id: "Website", name: "Webseiten" },
  { id: "App", name: "Mobile Apps" },
];

export default function Projects() {
  const [activeCategory, setActiveCategory] = useState("all");
  const [hoveredProject, setHoveredProject] = useState<string | null>(null);
  const [projects, setProjects] = useState<Project[]>([]);
  const [loading, setLoading] = useState(true);
  const isMobile = useIsMobile();
  const analytics = useAnalytics();

  // Track page visit and setup engagement tracking
  useEffect(() => {
    window.scrollTo(0, 0);
    analytics.trackPageView('/projects');
    analytics.trackEvent('Projects', 'Page Visit', 'Projects Portfolio');
    
    // Track time spent on projects page
    const startTime = Date.now();
    
    return () => {
      const timeSpent = Math.round((Date.now() - startTime) / 1000);
      if (timeSpent > 5) { // Only track if user spent more than 5 seconds
        analytics.trackEvent('Projects', 'Time on Page', 'Projects Portfolio', timeSpent);
      }
    };
  }, [analytics]);

  useEffect(() => {
    async function fetchProjects() {
      try {
        const { data, error } = await supabase
          .from('projects')
          .select('*')
          .order('created_at', { ascending: false });
          
        if (error) {
          console.error("Error fetching projects:", error);
          analytics.trackEvent('Projects', 'Data Error', 'Failed to fetch projects');
          return;
        }
        
        setProjects(data || []);
        analytics.trackEvent('Projects', 'Data Loaded', `${data?.length || 0} projects loaded`);
      } catch (err) {
        console.error("Failed to fetch projects:", err);
        analytics.trackEvent('Projects', 'Data Error', 'Network error fetching projects');
      } finally {
        setLoading(false);
      }
    }
    
    fetchProjects();
  }, [analytics]);

  // Fallback projects if none in database yet
  const projectsData = projects.length > 0 ? projects : [
    {
      id: "1",
      title: "E-Commerce Webseite",
      client: "Fashion Store",
      type: "Website",
      category: "website",
      image_url: "https://images.unsplash.com/photo-1486312338219-ce68d2c6f44d",
      url: "#",
      description: "Moderner Online-Shop mit optimiertem Einkaufserlebnis und integriertem Zahlungssystem."
    },
    {
      id: "2",
      title: "Fitness App",
      client: "FitLife",
      type: "App",
      category: "mobile",
      image_url: "https://images.unsplash.com/photo-1498050108023-c5249f4df085",
      url: "#",
      description: "Eine Fitness-App zur Nachverfolgung von Workouts, Ernährung und persönlichen Zielen."
    },
    {
      id: "3",
      title: "Restaurant Webseite",
      client: "Gourmet Kitchen",
      type: "Website",
      category: "website",
      image_url: "https://images.unsplash.com/photo-1531297484001-80022131f5a1",
      url: "#",
      description: "Elegante Website mit Online-Reservierungssystem und Menü-Präsentation."
    },
    {
      id: "4",
      title: "Reise Plattform",
      client: "Wanderlust",
      type: "Website",
      category: "website",
      image_url: "https://images.unsplash.com/photo-1488590528505-98d2b5aba04b",
      url: "#",
      description: "Eine umfassende Reiseplattform mit Buchungsmöglichkeiten und personalisierten Empfehlungen."
    },
    {
      id: "5",
      title: "Finanz Manager",
      client: "Money Wise",
      type: "App",
      category: "mobile",
      image_url: "https://images.unsplash.com/photo-1518770660439-4636190af475",
      url: "#",
      description: "Mobile App zur Verwaltung von Finanzen, Budgetierung und Ausgabenverfolgung."
    },
    {
      id: "6",
      title: "Immobilien Portal",
      client: "Home Finder",
      type: "Website",
      category: "website",
      image_url: "https://images.unsplash.com/photo-1461749280684-dccba630e2f6",
      url: "#",
      description: "Immobilienbörse mit fortschrittlicher Suchfunktion und virtuellen Besichtigungen."
    },
    {
      id: "7",
      title: "Event Management System",
      client: "EventPro",
      type: "Website",
      category: "website",
      image_url: "https://images.unsplash.com/photo-1519389950473-47ba0277781c",
      url: "#",
      description: "Umfassende Plattform zur Verwaltung von Events, Ticketverkauf und Teilnehmermanagement."
    },
    {
      id: "8",
      title: "Healthcare App",
      client: "MediCare",
      type: "App",
      category: "mobile",
      image_url: "https://images.unsplash.com/photo-1487058792275-0ad4aaf24ca7",
      url: "#",
      description: "App für Gesundheitsmonitoring, Arzttermine und Medikamentenerinnerungen."
    },
    {
      id: "9",
      title: "Unternehmenswebsite",
      client: "Tech Innovators",
      type: "Website",
      category: "website",
      image_url: "https://images.unsplash.com/photo-1483058712412-4245e9b90334",
      url: "#",
      description: "Corporate Website mit Fokus auf Markenidentität und Kundenkommunikation."
    },
  ];

  // Updated filtering logic to use type instead of category
  const filteredProjects = activeCategory === "all"
    ? projectsData
    : projectsData.filter(project => project.type === activeCategory);

  const handleCategoryChange = (categoryId: string) => {
    const categoryName = categories.find(cat => cat.id === categoryId)?.name || categoryId;
    
    // Track category filter usage
    analytics.trackButtonClick(`Category Filter: ${categoryName}`, 'Projects Page');
    analytics.trackEvent('Projects', 'Filter Used', categoryName);
    analytics.trackEvent('Projects', 'Category Change', `From ${activeCategory} to ${categoryId}`);
    
    // Track filter effectiveness
    const filteredCount = categoryId === "all" 
      ? projectsData.length 
      : projectsData.filter(project => project.type === categoryId).length;
    analytics.trackEvent('Projects', 'Filter Results', `${categoryName}: ${filteredCount} projects`);
    
    setActiveCategory(categoryId);
  };

  const handleCTAClick = () => {
    analytics.trackButtonClick('Contact CTA', 'Projects Page Bottom');
    analytics.trackEvent('Projects', 'CTA Click', 'Contact from Projects');
    analytics.trackNavigation('/projects', '/kontakt');
  };

  const handleProjectHover = (projectId: string, projectTitle: string) => {
    if (!isMobile) {
      analytics.trackEvent('Projects', 'Project Hover', projectTitle);
    }
  };

  return (
    <div className="min-h-screen flex flex-col">
      <Helmet>
        <title>Referenzprojekte | Web- & App-Entwicklung Portfolio | Walbostudios</title>
        <meta name="description" content="Entdecken Sie unsere Erfolgsgeschichten: Webseiten, Apps und digitale Lösungen für verschiedene Branchen. Referenzprojekte aus Fürth und Nürnberg." />
        <meta name="keywords" content="webentwicklung projekte, app entwicklung referenzen, webdesign portfolio, kundenreferenzen, digital agentur portfolio, responsive webdesign beispiele, ecommerce website entwicklung" />
        <link rel="canonical" href="https://walbostudios.com/projects" />
        <meta property="og:title" content="Referenzprojekte | Web- & App-Entwicklung Portfolio | Walbostudios" />
        <meta property="og:description" content="Entdecken Sie unsere Erfolgsgeschichten: Webseiten, Apps und digitale Lösungen für verschiedene Branchen." />
        <meta property="og:type" content="website" />
        <meta property="og:url" content="https://walbostudios.com/projects" />
        <meta property="og:image" content="https://walbostudios.com/lovable-uploads/walbo_logo.png" />
        <meta property="og:locale" content="de_DE" />
        <meta name="twitter:card" content="summary_large_image" />
        <meta name="twitter:title" content="Referenzprojekte | Web- & App-Entwicklung Portfolio" />
        <meta name="twitter:description" content="Entdecken Sie unsere Erfolgsgeschichten: Webseiten, Apps und digitale Lösungen für verschiedene Branchen." />
        <meta name="twitter:image" content="https://walbostudios.com/lovable-uploads/walbo_logo.png" />
        <script type="application/ld+json">{`
          {
            "@context": "https://schema.org",
            "@type": "CollectionPage",
            "headline": "Walbostudios Projektportfolio",
            "description": "Übersicht unserer Referenzprojekte in Web- und App-Entwicklung",
            "url": "https://walbostudios.com/projects",
            "about": {
              "@type": "CreativeWork",
              "name": "Webentwicklung und App-Entwicklung"
            },
            "contentLocation": {
              "@type": "Place",
              "name": "Fürth, Nürnberg"
            },
            "author": {
              "@type": "Organization",
              "name": "Walbostudios"
            },
            "mainEntity": [
              ${projectsData.map(project => `{
                "@type": "CreativeWork",
                "name": "${project.title}",
                "description": "${project.description?.replace(/"/g, '\\"') || ''}",
                "image": "${project.image_url}",
                "url": "${project.url || 'https://walbostudios.com/projects'}",
                "creator": {
                  "@type": "Organization",
                  "name": "Walbostudios"
                },
                "about": "${project.category}"
              }`).join(',')}
            ]
          }
        `}</script>
      </Helmet>
      <Header />
      
      <main className="flex-1">
        <ProjectsHero />

        {/* Filters */}
        <div className="bg-background py-8">
          <div className="container">
            <div className="flex flex-wrap items-center justify-center gap-3">
              {categories.map((category) => (
                <Button
                  key={category.id}
                  variant={activeCategory === category.id ? "default" : "outline"}
                  onClick={() => handleCategoryChange(category.id)}
                  className="rounded-full"
                >
                  {category.name}
                </Button>
              ))}
            </div>
          </div>
        </div>

        {/* Projects Grid */}
        <div className="bg-background">
          <div className="container">
            {loading ? (
              <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
                {Array(6).fill(0).map((_, index) => (
                  <div 
                    key={`skeleton-${index}`} 
                    className="rounded-xl overflow-hidden bg-muted/20 animate-pulse"
                  >
                    <div className="aspect-[4/3] w-full"></div>
                  </div>
                ))}
              </div>
            ) : (
              <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
                {filteredProjects.map((project, index) => (
                  <ProjectCard 
                    key={project.id}
                    project={project}
                    index={index}
                    hoveredProject={hoveredProject}
                    setHoveredProject={setHoveredProject}
                    isMobile={isMobile}
                    onProjectHover={handleProjectHover}
                    analytics={analytics}
                  />
                ))}
              </div>
            )}
            
            {/* Empty State */}
            {!loading && filteredProjects.length === 0 && (
              <div className="py-16 text-center">
                <h3 className="text-xl font-semibold mb-4">Keine Projekte in dieser Kategorie</h3>
                <p className="text-muted-foreground mb-6">Bitte wähle eine andere Kategorie oder schau später wieder vorbei.</p>
                <Button 
                  onClick={() => {
                    analytics.trackButtonClick('Show All Projects', 'Empty State');
                    analytics.trackEvent('Projects', 'Empty State Action', 'Show All Projects');
                    setActiveCategory("all");
                  }}
                >
                  Alle Projekte anzeigen
                </Button>
              </div>
            )}
          </div>
        </div>

        {/* Call to Action */}
        <div className="py-16 bg-blue-50/50 dark:bg-blue-950/30">
          <div className="container">
            <div className="max-w-3xl mx-auto text-center">
              <h2 className="text-3xl font-bold mb-4">Hast du ein Projekt im Sinn?</h2>
              <p className="text-xl text-muted-foreground mb-8">
                Lass uns gemeinsam deine Vision umsetzen und ein erfolgreiches digitales Produkt schaffen.
              </p>
              <Button asChild size="lg" onClick={handleCTAClick}>
                <a href="/kontakt">Jetzt anfragen</a>
              </Button>
            </div>
          </div>
        </div>
      </main>
      
      <Footer />
    </div>
  );
}

interface ProjectCardProps {
  project: Project;
  index: number;
  hoveredProject: string | null;
  setHoveredProject: (id: string | null) => void;
  isMobile: boolean;
  onProjectHover: (projectId: string, projectTitle: string) => void;
  analytics: ReturnType<typeof useAnalytics>;
}

function ProjectCard({ 
  project, 
  index, 
  hoveredProject, 
  setHoveredProject, 
  isMobile,
  onProjectHover,
  analytics 
}: ProjectCardProps) {
  const isHovered = hoveredProject === project.id;
  
  // Generate SEO-friendly alt text based on project type and title
  const generateAltText = () => {
    const location = project.type === "App" ? "App-Entwicklung" : "Webseite";
    return `${project.title} ${location} Projekt - Walbostudios`;
  };

  const handleProjectClick = () => {
    // Track detailed project interaction
    analytics.trackEvent('Projects', 'Project Click', project.title);
    analytics.trackEvent('Projects', 'Project Type Click', project.type, 1);
    analytics.trackButtonClick(`Project: ${project.title}`, 'Projects Grid');
    
    // Track project position in grid for UX insights
    analytics.trackEvent('Projects', 'Project Position Click', `Position ${index + 1}: ${project.title}`);
    
    // Track client-specific interactions if available
    if (project.client) {
      analytics.trackEvent('Projects', 'Client Project Click', `${project.client}: ${project.title}`);
    }
    
    // Track for conversion potential
    if (project.url && project.url !== '#') {
      analytics.trackOutboundLink(project.url);
      analytics.trackEvent('Projects', 'External Project Visit', project.url);
      analytics.trackEvent('Projects', 'Portfolio Exit Intent', project.title);
    } else {
      analytics.trackEvent('Projects', 'Placeholder Project Click', project.title);
    }
  };

  const handleMouseEnter = () => {
    if (!isMobile) {
      setHoveredProject(project.id);
      onProjectHover(project.id, project.title);
    }
  };

  const handleMouseLeave = () => {
    if (!isMobile) {
      setHoveredProject(null);
    }
  };

  return (
    <motion.a
      href={project.url || "#"}
      target="_blank"
      rel="noopener noreferrer" 
      className="group relative rounded-xl overflow-hidden"
      data-project-id={project.id}
      onMouseEnter={handleMouseEnter}
      onMouseLeave={handleMouseLeave}
      onClick={handleProjectClick}
      initial={{ opacity: 0, y: 20 }}
      whileInView={{ opacity: 1, y: 0 }}
      transition={{ duration: 0.5, delay: index * 0.1 }}
      viewport={{ once: true, margin: "-100px" }}
    >
      <div className="aspect-[4/3] w-full">
        <img
          src={project.image_url}
          alt={generateAltText()}
          className="w-full h-full object-cover object-center"
          loading="lazy"
          onLoad={() => {
            // Track image load performance
            analytics.trackEvent('Projects', 'Image Loaded', project.title);
          }}
          onError={() => {
            // Track image load errors
            analytics.trackEvent('Projects', 'Image Error', project.title);
          }}
        />
      </div>
      
      {/* Desktop overlay - only visible on hover */}
      {!isMobile && (
        <div
          className="absolute inset-0 bg-gradient-to-t from-black/80 via-black/40 to-transparent transition-opacity duration-300 flex flex-col justify-end p-6"
          style={{ opacity: isHovered ? 1 : 0 }}
        >
          <div className="flex items-center gap-2 mb-2">
            <div className="px-3 py-1 rounded-full bg-primary/90 text-white text-xs font-medium">
              {project.type}
            </div>
            {project.client && (
              <div className="px-3 py-1 rounded-full bg-white/20 backdrop-blur-sm text-white text-xs font-medium">
                {project.client}
              </div>
            )}
          </div>
          <h3 className="text-xl text-white font-semibold mb-2">{project.title}</h3>
          {project.description && (
            <p className="text-white/80 text-sm line-clamp-2 mb-3">{project.description}</p>
          )}
          <div className="flex items-center text-white/80 text-sm">
            <ExternalLink className="h-4 w-4 mr-1" aria-hidden="true" />
            <span>Projekt ansehen</span>
          </div>
        </div>
      )}

      {/* Mobile overlay - always visible, more compact */}
      {isMobile && (
        <div className="absolute bottom-0 left-0 right-0 bg-black/70 p-3 flex flex-col">
          <div className="flex items-center justify-between mb-1">
            <div className="px-2 py-0.5 rounded-full bg-primary/90 text-white text-xs font-medium">
              {project.type}
            </div>
            <div className="bg-white rounded-full p-1 shadow-sm">
              <ExternalLink className="h-4 w-4 text-blue-600" aria-hidden="true" />
            </div>
          </div>
          <h3 className="text-sm text-white font-medium truncate">{project.title}</h3>
        </div>
      )}
      
      {/* Desktop external link icon */}
      {!isMobile && isHovered && (
        <motion.div 
          className="absolute top-4 right-4 bg-white rounded-full p-2 shadow-lg" 
          initial={{ scale: 0, rotate: -180 }} 
          animate={{ scale: 1, rotate: 0 }} 
          transition={{ duration: 0.3 }} 
          aria-hidden="true"
        >
          <ExternalLink className="h-5 w-5 text-blue-600" />
        </motion.div>
      )}
    </motion.a>
  );
}
